const Gio = imports.gi.Gio;
const Gtk = imports.gi.Gtk;

const Me = imports.misc.extensionUtils.getCurrentExtension();

const _ = imports.gettext.domain(Me.uuid).gettext;

const SETTINGS_DISABLE_MESSAGE_TRAY = "disable-message-tray";

let settings;

function init() {
    imports.gettext.bindtextdomain(Me.uuid, Me.path + "/locale");
    const GioSSS = Gio.SettingsSchemaSource;

    let schemaSource = GioSSS.new_from_directory(Me.path + "/schemas", 
            GioSSS.get_default(), false);

    let schemaObj = schemaSource.lookup(Me.metadata["settings-schema"], true);
    if(!schemaObj) {
        throw new Error("Schema " + Me.metadata["settings-schema"] + " could not be found for extension " +
                        Me.uuid + ". Please check your installation.");
    }

    settings = new Gio.Settings({ settings_schema: schemaObj });
}

function buildPrefsWidget() {
    let frame = new Gtk.Box({
        orientation: Gtk.Orientation.VERTICAL,
        border_width: 10
    });

    let hbox = new Gtk.Box({
        orientation: Gtk.Orientation.HORIZONTAL
    });

    let vbox = new Gtk.Box({
        orientation: Gtk.Orientation.VERTICAL,
        margin: 20,
        margin_top: 10
    });

    let settingLabel = new Gtk.Label({
        label: _("Disable message tray"),
        xalign: 0
    });

    let settingSwitch = new Gtk.Switch({
        active: settings.get_boolean(SETTINGS_DISABLE_MESSAGE_TRAY)
    });
    settingSwitch.connect("notify::active", function(button) {
        settings.set_boolean(SETTINGS_DISABLE_MESSAGE_TRAY, button.active);
    });

    settingLabel.set_tooltip_text(_("Shall the message tray be disabled"));
    settingSwitch.set_tooltip_text(_("Shall the message tray be disabled"));

    hbox.pack_start(settingLabel, true, true, 0);
    hbox.add(settingSwitch);

    vbox.add(hbox);

    frame.add(vbox);
    frame.show_all();
    return frame;
}
